SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- ESTE SP RETORNA UN RESUMEN DE LA BUSQUEDA DE INTERACCIONES DE ALLEGRO PARA INDETIFICAR LOS YA TRANSCRITOS O INPROCESS SEGUN LOS FILTROS RECIBIDOS 
-- FUNCIONA IGUAL QUE LA FUNCION EN KNEX
CREATE PROCEDURE [dbo].[GetAsyncBillingInteractions] (
   	@VCC					VARCHAR(50) = NULL,
	@IP						VARCHAR(50),						-- IP DEL SERVIDOR PARA LA BASE I6
	@Type					INT,								-- FLAG PARA INDICAR SI EL SERVIDOR I6 SE ENCUENTRA LOCAL O REMOTO
	@InteractionType		VARCHAR(50) = NULL,
	@StartDate				DATETIME = '1980-01-01T00:00:00',
    @EndDate				DATETIME = '2050-01-01T23:59:59',
	@StartHour				VARCHAR(50) = NULL,
	@EndHour				VARCHAR(50) = NULL,
	@Campaigns				VARCHAR(MAX) = NULL,
 	@Agents					VARCHAR(MAX) = NULL,
   	@DispositionCodes		VARCHAR(MAX) = NULL,
   	@Origins				VARCHAR(100) = NULL,
	@InteractionIds         VARCHAR(MAX) = NULL,
	@CharsPerPhrase			INT = 0
	
)
AS 
BEGIN 
	-- SETTEAMOS VALORES MINIMOS PARA LAS HORAS DE INICIO Y FIN
	IF (@StartHour IS NOT NULL AND @StartHour = '') SET @StartHour = '00:00:00'
	IF (@EndHour IS NOT NULL AND @EndHour = '') SET @EndHour = '23:59:59'

	-- CREAMOS UNA TABLA TEMPORAL PARA INSERTAR LOS REGISTROS DE LA HDI6
	CREATE TABLE #TMP_HD_INTERACTIONS
	(
		vcc VARCHAR(50), 
		id VARCHAR(250), 
		folder VARCHAR(50),
		exportedContent VARCHAR(250),  
		channel VARCHAR(50), 
		campaign VARCHAR(50), 
		startDate DATETIME,
		endDate DATETIME,
		account VARCHAR(50), 
		initiative VARCHAR(50), 
		contactName VARCHAR(250), 
		firstTakedAgent VARCHAR(50), 
		lastTakedAgent VARCHAR(50), 
		isTaken VARCHAR(50), 
		totalMessages INT,
		durationTime VARCHAR(50),  
		attentionTime VARCHAR(50), 
		dispositionCode VARCHAR(250), 
		dispositionTreePath VARCHAR(250), 
		rawChar INT,
		RN INT
	)

	-- EJECUTAMOS EL SP DE CONSULTA QUE LLENARA LA TABLA TEMPORAL
	EXEC [dbo].[GetAsyncInteractions]
		@Ip = @IP, @VCC = @VCC, @Type = @Type, @InteractionType = @InteractionType, @StartDate = @StartDate, 
		@EndDate = @EndDate, @StartHour = @StartHour, @EndHour = @EndHour, @Campaigns = @Campaigns, @Agents = @Agents,
		@DispositionCodes = @DispositionCodes, @Origins = @Origins,  @InteractionIds = @InteractionIds, @UniqueIds = 0, @ResultType = 'DETAILED'

	-- DECLARAMOS UNA VARIABLE PARA PARA EL TOTALDE RESULTADOS
	DECLARE @TOTAL_INTERACTIONS INT = 0

	-- SETTEAMOS EL NUMERO DE REGISTROS A LA VARIABLE DE TOTAL
	SELECT @TOTAL_INTERACTIONS = COUNT(*) FROM #TMP_HD_INTERACTIONS
	
	IF @TOTAL_INTERACTIONS = 0 
	BEGIN
		-- SI NO EXISTEN RESULTADOS EN HD LLENAMOSUN RESULTADOS CON 0
		SELECT @InteractionType												'interactionType',
				0															'totalInteractionDetails',
				0															'alreadyTranscribedInteraction',
				0															'inProcessInteraction',
				0															'notTranscribedInteraction',
				0															'totalPhrases',
				0															'totalRawChars',
				0															'totalRawPhrases'
	END 
	ELSE
	BEGIN
		-- CRUZAMOS LA TABLA TEMPORAL DE INTERACCIONES ASINCRONAS CON LA TABLA LOCAL INTERACTION PARA LAS INTERACCIONES ASINCRONAS YA REGISTRADAS
		SELECT HDI.[channel]												'interactionType',
				COUNT(*)													'totalInteractionDetails',
				SUM(CASE WHEN (AI.[VCC] IS NOT NULL 
					AND AI.[IsTranscribed] = 1) THEN 1 ELSE 0 END)			'alreadyTranscribedInteraction',
				0															'inProcessInteraction',
				SUM(CASE WHEN (AI.[VCC] IS NULL 
					OR AI.[IsTranscribed] <> 1) THEN 1 ELSE 0 END)			'notTranscribedInteraction',
				SUM(ISNULL(AI.[TotalPhrases], 0))							'totalPhrases',
				-- CUANDO TENEMOS VALIDPHRASES, YA NO CONTAMOS LAS RAWCHAR 
				SUM(
					CASE WHEN (AI.[TotalPhrases] IS NULL 
							OR AI.[TotalPhrases] = 0)
					THEN (
						ISNULL(AI.[RawChar], ISNULL(HDI.[rawChar], 0))
					)
					ELSE 0 END
				)															'totalRawChars',
				SUM(
					CASE WHEN (AI.[TotalPhrases] IS NULL 
							OR AI.[TotalPhrases] = 0)
					THEN (
						-- SI RAWCHAR ES NULL, SE DEBE VALUAR COMO MINIMO 1 FRASE(@CharsPerPhrase)
						-- CEILING(ISNULL(AI.[RawChar], ISNULL(HDI.[rawChar], @CharsPerPhrase)) * 1.00 / @CharsPerPhrase)
						CEILING(ISNULL(AI.[RawChar], ISNULL(HDI.[rawChar], 0)) * 1.00 / @CharsPerPhrase)
					)
					ELSE 0 END
				)															'totalRawPhrases'
			FROM #TMP_HD_INTERACTIONS HDI (NOLOCK)
			LEFT JOIN [dbo].[AsyncInteraction] AI (NOLOCK)
				ON HDI.[vcc] = AI.[VCC]
					AND HDI.[channel] = AI.[Channel]
					AND HDI.[campaign] = AI.[Campaign]
					AND HDI.[id] = AI.[ID]
					AND HDI.[endDate] = AI.[EndDate]
			GROUP BY HDI.[vcc],
						HDI.[channel]
			--ORDER BY AI.[TotalPhrases], AI.[RawChar] DESC, HDI.[RawChar] DESC

	END

END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
