SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetAudiosByProcessId]
(
	@VCC		VARCHAR(50),
	@ProcessId	VARCHAR(50)
)
AS
BEGIN
	SET NOCOUNT ON

	BEGIN
		-- Actualiza en el primer momento que se consulta a estos registros, con el valor 1 en el campo IsProcess. Indica que se encuentra utilizado por un proceso.
		UPDATE [dbo].[Audio] SET
			[dbo].[Audio].[IsProcess] = 1	-- Indicar que se esta tomando como procesando para que ningun otro procesamiento en parelelo pueda utilizar el registro.
		-- Retornamos todas las columnas a listar.
		OUTPUT INSERTED.[VCC]							'vcc',
				PA.[ProcessId]							'processId',
				INSERTED.[ID]							'id',
				INSERTED.[Section]						'section',
				INSERTED.[Part]							'part',
				INSERTED.[StartDate]					'startDate',
				INSERTED.[EndDate]						'endDate',
				INSERTED.[Campaign]						'campaign',
				INSERTED.[DispositionCode]				'dispositionCode',
				INSERTED.[Agent]						'agent',
				INSERTED.[Type]							'origin',
				E.[Name]								'name',
				E.[Type]								'environmentType',
				E.[Description]							'description',
				E.[FTPDirectory]						'ftpDirectory',
				E.[ApiHost]								'apiHost',
				E.[ApiPort]								'apiPort',
				E.[ApiUser]								'apiUser',
				E.[ApiPassword]							'apiPassword',
				E.[DbDisabled]							'dbDisabled',
				E.[DbServer]							'dbServer',
				E.[DbPort]								'dbPort',
				E.[DbUser]								'dbUser',
				E.[DbPassword]							'dbPassword',
				E.[PbxDisabled]							'pbxDisabled',
				E.[PbxServer]							'pbxServer',
				E.[PbxPort]								'pbxPort',
				E.[PbxUser]								'pbxUser',
				E.[PbxPassword]							'pbxPassword'
		FROM
			[dbo].[ProcessAudio] PA WITH (NOLOCK)
			INNER JOIN [dbo].[Audio] A WITH (NOLOCK) ON CONCAT(A.[ID], '_', A.[Section], '_', A.[Part]) = CONCAT(PA.[AudioId], '_', PA.[Section], '_', PA.[Part])
			INNER JOIN [dbo].[Process] P WITH (NOLOCK) ON PA.ProcessId = P.[Name]
			INNER JOIN [dbo].[Environment] E WITH (NOLOCK) ON P.[Environment] = E.[Name]

		WHERE
			A.[VCC] = @VCC
			AND PA.[ProcessId] = @ProcessId
			AND ISNULL(A.[IsTranscribed], 0) = 0	-- Retornar sOlo las interacciones que no hayan sido transcritas.
			AND ISNULL(A.[IsProcess], 0) = 0		-- Retornar sOlo las interacciones que no hayan sido tomadas por otro procesamiento.
	END

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
