SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetCampaignFulfillment] (
	@Instance VARCHAR(50) = NULL,
	@InitialDate DATETIME = NULL,
	@EndDate DATETIME = NULL,
	@IdCampaign VARCHAR(MAX) = 'GetCampaignFulfillment',
	@IdEvaluationFormat VARCHAR(MAX) = 'GetCampaignFulfillment',
	@IdAgent VARCHAR(MAX) = 'GetCampaignFulfillment',
	@IdWorkGroup VARCHAR(MAX) = 'GetCampaignFulfillment',
	@IdAttentionLevel VARCHAR(MAX) = 'GetCampaignFulfillment',
	@IdEvaluationPlan VARCHAR(MAX) = 'GetCampaignFulfillment',
	@IdGroup VARCHAR(MAX) = 'GetCampaignFulfillment',
	@IdSubGroup VARCHAR(MAX) = 'GetCampaignFulfillment',
	@IdAbility VARCHAR(MAX) = 'GetCampaignFulfillment',
	@IdAuditor VARCHAR(MAX) = 'GetCampaignFulfillment'
)
AS
BEGIN
	DECLARE @INTERACTION_TOTAL INT = 0
	DECLARE @INTERACTION_APPROVED INT = 0
	DECLARE @INTERACTION_DISAPPROVED INT = 0
	DECLARE @INTERACTION_RATIO INT = 0
		
	
	SET NOCOUNT ON;

	WITH 

		-- DECLARAMOS UNA CTE PARA DEPOSITAR LAS LLAMADAS EVALUADAS CON SU ULTIMA FECHA DE EVALUACION
		CteTotalInteractionsEvaluated AS (
			SELECT
				ER.[IdCampaign] 
				, ER.[IdEvaluationPlan]
				, ER.[IdInteraction] 
				, ER.[EvaluationDate] LastEvaluationDate 
				, ER.[IdAuditor]
				, AEP.[Score]
				, ER.[MinQualificationAcceptable]
				, RN = ROW_NUMBER() OVER(PARTITION BY ER.[IdCampaign], ER.[IdEvaluationPlan], ER.[IdInteraction], ER.[IdAuditor] ORDER BY ER.[EvaluationDate] DESC)
			FROM
				EvaluationResult ER
			LEFT JOIN AuditorEvaluationPlan AEP 
				ON AEP.[Instance] = ER.[Instance] 
					AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan] 
					AND AEP.[IdInteraction] = ER.[IdInteraction]
					AND AEP.[IdAuditor] = ER.[IdAuditor]
			WHERE
				ER.Instance = @Instance
				AND ER.EvaluationDate BETWEEN @InitialDate AND @EndDate
				AND CASE WHEN @IdAgent = 'GetCampaignFulfillment' THEN 'GetCampaignFulfillment' ELSE ER.IdAgent END IN (SELECT Value FROM [dbo].[split](@IdAgent,','))
				AND CASE WHEN @IdCampaign = 'GetCampaignFulfillment' THEN 'GetCampaignFulfillment' ELSE ER.IdCampaign END IN (SELECT Value FROM [dbo].[split](@IdCampaign,','))
				AND CASE WHEN @IdEvaluationFormat = 'GetCampaignFulfillment' THEN 'GetCampaignFulfillment' ELSE ER.IdEvaluationFormat END IN (SELECT Value FROM [dbo].[split](@IdEvaluationFormat,','))
				AND CASE WHEN @IdEvaluationPlan = 'GetCampaignFulfillment' THEN 'GetCampaignFulfillment' ELSE ER.IdEvaluationPlan END IN (SELECT Value FROM [dbo].[split](@IdEvaluationPlan,','))
				AND ER.[IdAuditor] LIKE CASE WHEN @IdAuditor = 'GetCampaignFulfillment' THEN '%' ELSE 'SPEECH' END AND ER.IdAuditor <> CASE WHEN @IdAuditor = 'GetCampaignFulfillment' THEN 'SPEECH' ELSE 'B_I_G_C_H_E_E_S_E' END
		)
	
	SELECT 
		@INTERACTION_TOTAL = (
			SELECT COUNT(TEI.[IdInteraction])
			FROM CteTotalInteractionsEvaluated TEI 
			WHERE TEI.[RN] = 1
		),
		@INTERACTION_APPROVED = (
			SELECT COUNT(TEI.[IdInteraction])
				FROM CteTotalInteractionsEvaluated TEI 
				WHERE TEI.[RN] = 1
					AND TEI.[Score] >= TEI.[MinQualificationAcceptable]
			
		)
	
	
	IF (@INTERACTION_TOTAL > 0)
	BEGIN
		SET @INTERACTION_RATIO = 100 * @INTERACTION_APPROVED / @INTERACTION_TOTAL 
		SET @INTERACTION_DISAPPROVED = @INTERACTION_TOTAL - @INTERACTION_APPROVED

		SELECT @INTERACTION_DISAPPROVED AS 'disapproved',
			@INTERACTION_TOTAL AS 'evaluated', 
			@INTERACTION_APPROVED AS 'approved',
			@INTERACTION_RATIO AS 'ApprovalPercentage'
	END
	ELSE
	BEGIN
		SET @INTERACTION_TOTAL = 0
		SET @INTERACTION_RATIO = 0
		SET @INTERACTION_APPROVED = 0
		SET @INTERACTION_DISAPPROVED = 0

	END
		
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
