SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[GetTopAgents] (
	@Instance VARCHAR(50) = NULL,
	@InitialDate DATETIME = NULL,
	@EndDate DATETIME = NULL,
	@TopQuantity INT = 10,
	@TopBest BIT = 1,
	@IdCampaign VARCHAR(MAX) = 'GetTopAgents',
	@IdEvaluationFormat VARCHAR(MAX) = 'GetTopAgents',
	@IdAgent VARCHAR(MAX) = 'GetTopAgents',
	@IdWorkGroup VARCHAR(MAX) = 'GetTopAgents',
	@IdAttentionLevel VARCHAR(MAX) = 'GetTopAgents',
	@IdEvaluationPlan VARCHAR(MAX) = 'GetTopAgents',
	@IdGroup VARCHAR(MAX) = 'GetTopAgents',
	@IdSubGroup VARCHAR(MAX) = 'GetTopAgents',
	@IdAbility VARCHAR(MAX) = 'GetTopAgents',
	@IdAuditor VARCHAR(MAX) = 'GetTopAgents'
)
AS
BEGIN
	DECLARE @InteractionsEvaluated INT = 0;
	DECLARE @InteractionsApproved INT = 0;

	SET NOCOUNT ON;

	WITH 
	-- DECLARAMOS UNA CTE PARA DEPOSITAR LAS LLAMADAS EVALUADAS CON SU ULTIMA FECHA DE EVALUACION
	CteTotalInteractionsEvaluated AS (
		SELECT DISTINCT ER.[Instance], 
						ER.[IdEvaluationPlan], 
						ER.[IdAuditor], 
						ER.[IdAgent], 
						ER.[IdInteraction],
						AEP.[Score],
						ER.[MinQualificationAcceptable], 
						RN = ROW_NUMBER() OVER(PARTITION BY ER.[Instance], ER.[IdEvaluationPlan], ER.[IdAuditor], ER.[IdAgent], ER.[IdInteraction] ORDER BY ER.[EvaluationDate] DESC)
			FROM EvaluationResult ER (NOLOCK)
			LEFT JOIN AuditorEvaluationPlan AEP (NOLOCK) 
				ON AEP.[Instance] = ER.[Instance]
					AND AEP.[IdEvaluationPlan] = ER.[IdEvaluationPlan]
					AND AEP.[IdAgent] = ER.[IdAgent]
					AND AEP.[IdInteraction] = ER.[IdInteraction]
			WHERE ER.[Instance] = @Instance
				AND ER.[TimeStamp] BETWEEN @InitialDate AND @EndDate
				AND CASE WHEN @IdAgent = 'GetTopAgents' THEN 'GetTopAgents' ELSE AEP.[IdAgent] END IN (SELECT Value FROM [dbo].[split](@IdAgent,','))
				AND CASE WHEN @IdCampaign = 'GetTopAgents' THEN 'GetTopAgents' ELSE AEP.[IdCampaign] END IN (SELECT Value FROM [dbo].[split](@IdCampaign,','))
				AND CASE WHEN @IdEvaluationFormat = 'GetTopAgents' THEN 'GetTopAgents' ELSE ER.[IdEvaluationFormat] END IN (SELECT Value FROM [dbo].[split](@IdEvaluationFormat,','))
				AND CASE WHEN @IdEvaluationPlan = 'GetTopAgents' THEN 'GetTopAgents' ELSE AEP.[IdEvaluationPlan] END IN (SELECT Value FROM [dbo].[split](@IdEvaluationPlan,','))
				AND ER.[IdAuditor] LIKE CASE WHEN @IdAuditor = 'GetTopAgents' THEN '%' ELSE 'SPEECH' END AND ER.[IdAuditor] <> CASE WHEN @IdAuditor = 'GetTopAgents' THEN 'SPEECH' ELSE 'B_I_G_C_H_E_E_S_E' END
				AND AEP.[Instance] IS NOT NULL
	)
	-- HACEMOS EL SELECT RESUMEN SOBRE EL RESULTADO DE LA CTE
	SELECT IE.[IdAgent] 'AgentDescription',
		IE.[IdAgent] 'AgentId',
		COUNT(*) 'Evaluated',
		SUM(CASE WHEN IE.[Score] >= IE.[MinQualificationAcceptable] THEN 1 ELSE 0 END) 'Approved', 
		SUM(CASE WHEN IE.[Score] < IE.[MinQualificationAcceptable] THEN 1 ELSE 0 END) 'Disapproved',
		SUM(CASE WHEN IE.[Score] >= IE.[MinQualificationAcceptable] THEN 1 ELSE 0 END) * 100 / COUNT(*) 'ApprovalPercentage',
		SUM(CASE WHEN IE.[Score] < IE.[MinQualificationAcceptable] THEN 1 ELSE 0 END) * 100 / COUNT(*) 'DisapprovalPercentage'
	FROM CteTotalInteractionsEvaluated IE (NOLOCK)
	WHERE IE.[RN] = 1
	GROUP BY IE.[Instance], IE.[IdAgent], IE.[RN]
	ORDER BY 
		-- DEPENDIENDO QUE TOP BUSCAMOS (MEJOR O PEOR) AGREGAMOS EL ORDER BY AL FINAL SOBRE LA COLUMNA DE PORCENTAJE
		CASE @TopBest 
			WHEN 1
				THEN SUM(CASE WHEN IE.[Score] >= IE.[MinQualificationAcceptable] THEN 1 ELSE 0 END) * 100 / COUNT(*)
		END DESC,
		CASE @TopBest
			WHEN 0 
				THEN SUM(CASE WHEN IE.[Score] < IE.[MinQualificationAcceptable] THEN 1 ELSE 0 END) * 100 / COUNT(*)
		END DESC

		


	/*
	WITH 
		-- DECLARAMOS UNA CTE PARA DEPOSITAR LAS LLAMADAS EVALUADAS CON SU ULTIMA FECHA DE EVALUACION
		CteTotalInteractionsEvaluated AS (
			-- Llamadas evaluadas con su ultima calificacion, agente evaluado y boolean indicador de aprobaciÃ³n
			SELECT
				ER.IdCampaign,
				ER.IdInteraction,
				ER.IdAgent,
				SUM(ER.Qualification) TotalQualification,
				CASE
					WHEN SUM(ER.Qualification) >= ER.MinQualificationAcceptable THEN 1
					ELSE 0
				END InteractionApproved
			FROM
				EvaluationResult ER,
				(
					-- Llamadas evaluadas con su ultima fecha de evaluacion
					SELECT
						IdCampaign,
						IdInteraction,
						IdAgent,
						MAX(EvaluationDate) LastEvaluationDate
					FROM
						EvaluationResult
					WHERE
						EvaluationResult.Instance = @Instance
						AND EvaluationDate BETWEEN @InitialDate AND @EndDate
						AND CASE WHEN @IdAgent = 'GetTopAgents' THEN 'GetTopAgents' ELSE IdAgent END IN (SELECT Value FROM [dbo].[split](@IdAgent,','))
						AND CASE WHEN @IdCampaign = 'GetTopAgents' THEN 'GetTopAgents' ELSE IdCampaign END IN (SELECT Value FROM [dbo].[split](@IdCampaign,','))
						AND CASE WHEN @IdEvaluationFormat = 'GetTopAgents' THEN 'GetTopAgents' ELSE IdEvaluationFormat END IN (SELECT Value FROM [dbo].[split](@IdEvaluationFormat,','))
						AND CASE WHEN @IdEvaluationPlan = 'GetTopAgents' THEN 'GetTopAgents' ELSE IdEvaluationPlan END IN (SELECT Value FROM [dbo].[split](@IdEvaluationPlan,','))
						AND IdAuditor LIKE CASE WHEN @IdAuditor = 'GetTopAgents' THEN '%' ELSE 'SPEECH' END AND IdAuditor <> CASE WHEN @IdAuditor = 'GetTopAgents' THEN 'SPEECH' ELSE 'B_I_G_C_H_E_E_S_E' END
					GROUP BY
						IdCampaign,
						IdInteraction,
						idAgent
				) LastEvaluation
			WHERE
				ER.IdInteraction = LastEvaluation.IdInteraction AND
				ER.EvaluationDate = LastEvaluation.LastEvaluationDate
			GROUP BY
				ER.IdCampaign,
				ER.IdInteraction,
				ER.IdAgent,
				ER.MinQualificationAcceptable
		)

	SELECT TOP (@TopQuantity)
		InteractionsEvaluated.IdAgent AgentId,
		InteractionsEvaluated.IdAgent AgentDescription,
		(InteractionsApproved.InteractionsApproved * 100 / InteractionsEvaluated.InteractionsEvaluated) ApprovalPercentage,
		InteractionsEvaluated.InteractionsEvaluated Evaluated,
		InteractionsApproved.InteractionsApproved Approved
	FROM
		(
			-- Llamadas evaluadas para cada agente
			SELECT
				InteractionTotalQualification.IdAgent,
				Count(*) InteractionsEvaluated
			FROM
				CteTotalInteractionsEvaluated InteractionTotalQualification
			GROUP BY
				InteractionTotalQualification.IdAgent
		) InteractionsEvaluated,
		(
			-- Llamadas aprobadas para cada agente
			SELECT
				InteractionTotalQualification.IdAgent,
				SUM(InteractionTotalQualification.InteractionApproved) InteractionsApproved
			FROM
				CteTotalInteractionsEvaluated InteractionTotalQualification
			GROUP BY
				InteractionTotalQualification.IdAgent
		) InteractionsApproved
	WHERE
		InteractionsEvaluated.IdAgent = InteractionsApproved.IdAgent
	ORDER BY
		CASE @TopBest
			WHEN 1
			THEN (InteractionsApproved.InteractionsApproved * 100 / InteractionsEvaluated.InteractionsEvaluated)
		END DESC,
		CASE @TopBest
			WHEN 0
			THEN (InteractionsApproved.InteractionsApproved * 100 / InteractionsEvaluated.InteractionsEvaluated)
		END ASC
	*/
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
